alphaTesting: Testing the difference of alpha outperformance ratios

alphaTestingR Documentation

Testing the difference of alpha outperformance ratios

Description

Function which performs the testing of the difference of alpha outperformance ratios.

Usage

alphaTesting(x, y, factors = NULL, control = list(), screen_beta = NULL)

Arguments

x

Vector (of length T) of returns for the first fund. NA values are allowed.

y

Vector (of length T) returns for the second fund. NA values are allowed.

factors

Matrix (T \times K) of T returns for the K factors. NA values are allowed.

control

Control parameters (see *Details*).

screen_beta

Boolean to screen all factors' coefficients (beta). Default: screen_beta = NULL, in which case the value is taken from control$screen_beta (itself defaulting to FALSE). When supplied directly, the argument takes precedence. screen_beta = TRUE requires factors.

Details

The alpha measure (Treynor and Black 1973, Carhart 1997, Fung and Hsieh 2004) is one industry standard for measuring the absolute risk adjusted performance of hedge funds. This function performs the testing of alpha outperformance ratio difference for two funds.

For the testing, only the intersection of non-NA observations for the two funds are used.

The argument control is a list that can supply any of the following components:

  • 'hac' Heteroscedastic-autocorrelation consistent standard errors. Default: hac = FALSE.

Value

A list with the following components:

n: Number of non-NA concordant observations.

alpha: Vector (of length 2) of the two funds' unconditional alphas.

dalpha: Difference of the two funds' alphas.

tstat: t-stat of the alpha difference.

pval: p-value of the test of equal alpha.

When screen_beta = TRUE, alpha is a matrix (one row per coefficient, the first being the alpha) and dalpha, tstat and pval are vectors with one entry per coefficient; the print method reports the alpha (first) coefficient only.

Note

Further details on the methodology with an application to the hedge fund industry is given in Ardia and Boudt (2018).

Some internal functions where adapted from Michael Wolf MATLAB code.

Author(s)

David Ardia and Kris Boudt.

References

Ardia, D., Boudt, K. (2015). Testing equality of modified Sharpe ratios. Finance Research Letters 13, 97–104.

Ardia, D., Boudt, K. (2018). The peer performance ratios of hedge funds. Journal of Banking and Finance 87, 351–368.

Barras, L., Scaillet, O., Wermers, R. (2010). False discoveries in mutual fund performance: Measuring luck in estimated alphas. Journal of Finance 65(1), 179–216.

Sharpe, W.F. (1994). The Sharpe ratio. Journal of Portfolio Management 21(1), 49–58.

Ledoit, O., Wolf, M. (2008). Robust performance hypothesis testing with the Sharpe ratio. Journal of Empirical Finance 15(5), 850–859.

Storey, J. (2002). A direct approach to false discovery rates. Journal of the Royal Statistical Society B 64(3), 479–498.

See Also

alphaScreening.

Examples

## Load the data (randomized data of monthly hedge fund returns)
data("hfdata")
x = hfdata[,1]
y = hfdata[,2]

## Run alpha testing
alphaTesting(x, y)

PeerPerformance documentation built on Aug. 3, 2026, 1:08 a.m.