plot.rollScreening: Plot a rolling peer performance screening

View source: R/rollScreening.R

plot.rollScreeningR Documentation

Plot a rolling peer performance screening

Description

Time-series plot of the rolling peer performance ratios produced by rollScreening.

Usage

## S3 method for class 'rollScreening'
plot(x, what = NULL, legend = TRUE, ...)

Arguments

x

A rollScreening object.

what

Either "heterogeneity" (1-\bar\pi^0) or "ratios" (the averaged \bar\pi^+,\bar\pi^0,\bar\pi^-). Default: "heterogeneity" for a beta screening, "ratios" otherwise.

legend

A logical value indicating whether to draw a legend. Default: TRUE.

...

Further graphical arguments.

Value

Invisibly returns x.

Author(s)

David Ardia and Kris Boudt.

See Also

rollScreening.

Examples


  data("hfdata")
  roll <- rollScreening(hfdata[, 1:15], width = 36, by = 12,
                        control = list(nCore = 1))
  plot(roll)


PeerPerformance documentation built on Aug. 3, 2026, 1:08 a.m.