View source: R/rollScreening.R
| plot.rollScreening | R Documentation |
Time-series plot of the rolling peer performance ratios produced
by rollScreening.
## S3 method for class 'rollScreening'
plot(x, what = NULL, legend = TRUE, ...)
x |
A |
what |
Either |
legend |
A logical value indicating whether to draw a legend. Default:
|
... |
Further graphical arguments. |
Invisibly returns x.
David Ardia and Kris Boudt.
rollScreening.
data("hfdata")
roll <- rollScreening(hfdata[, 1:15], width = 36, by = 12,
control = list(nCore = 1))
plot(roll)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.