plot.rollScreening: Plot a rolling peer performance screening
Description
Time-series plot of the rolling peer performance ratios produced
by rollScreening.
Usage
# S3 method for rollScreening
plot(x, what = NULL, legend = TRUE, ...)
Value
Invisibly returns x.
Arguments
x
A rollScreening object.
what
Either "heterogeneity" (\(1-\bar\pi^0\)) or
"ratios" (the averaged \(\bar\pi^+,\bar\pi^0,\bar\pi^-\)). Default:
"heterogeneity" for a beta screening, "ratios" otherwise.
legend
A logical value indicating whether to draw a legend. Default:
TRUE.